==> jc-1.4.0.tar.gz: soot/VoidType.h <==
// public class soot.VoidType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class fddfad630263b66b soot_VoidType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_VoidType_H_
#define _JC_soot_VoidType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_VoidType$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_VoidType$sub_refs	_jc_soot_VoidType$sub_refs;
typedef struct _jc_soot_VoidType$sub_nonrefs	_jc_soot_VoidType$sub_nonrefs;
typedef struct _jc_soot_VoidType$refs	_jc_soot_VoidType$refs;
typedef struct _jc_soot_VoidType$nonrefs	_jc_soot_VoidType$nonrefs;
typedef struct _jc_soot_VoidType$object	_jc_soot_VoidType$object;

typedef const struct _jc_soot_VoidType$vmethods	_jc_soot_VoidType$vmethods;
typedef const struct _jc_soot_VoidType$vtable	_jc_soot_VoidType$vtable;
typedef const struct _jc_soot_VoidType$vtype	_jc_soot_VoidType$vtype;

// Constructors
extern void _jc_soot_VoidType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_VoidType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_object *);
extern jboolean _jc_soot_VoidType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_VoidType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_VoidType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_VoidType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_VoidType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_VoidType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_VoidType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_VoidType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_VoidType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_VoidType$object *_jc_soot_VoidType$method$v$1ec4381f84c71d19(_jc_env *);

// Virtual methods structure
struct _jc_soot_VoidType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_VoidType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_VoidType$object *);
};

// Vtable
struct _jc_soot_VoidType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_VoidType$vmethods	soot_VoidType;
};

// Vtype
struct _jc_soot_VoidType$vtype {
	_jc_type			type;
	_jc_soot_VoidType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_VoidType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_VoidType$refs {
    _jc_soot_VoidType$sub_refs	soot_VoidType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_VoidType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_VoidType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_VoidType$sub_nonrefs	soot_VoidType;
};

// Object instance structure
struct _jc_soot_VoidType$object {
	_jc_soot_VoidType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_VoidType$vtype	*vtype;
	_jc_soot_VoidType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_VoidType$vtype _jc_soot_VoidType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_VoidType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_VoidType$class_object;

#endif	/* _JC_soot_VoidType_H_ */

==> jc-1.4.6.tar.gz: soot/VoidType.h <==
// public class soot.VoidType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class fddfad630263b66b soot_VoidType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_VoidType_H_
#define _JC_soot_VoidType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_VoidType$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_VoidType$sub_refs	_jc_soot_VoidType$sub_refs;
typedef struct _jc_soot_VoidType$sub_nonrefs	_jc_soot_VoidType$sub_nonrefs;
typedef struct _jc_soot_VoidType$refs	_jc_soot_VoidType$refs;
typedef struct _jc_soot_VoidType$nonrefs	_jc_soot_VoidType$nonrefs;
typedef struct _jc_soot_VoidType$object	_jc_soot_VoidType$object;

typedef const struct _jc_soot_VoidType$vmethods	_jc_soot_VoidType$vmethods;
typedef const struct _jc_soot_VoidType$vtable	_jc_soot_VoidType$vtable;
typedef const struct _jc_soot_VoidType$vtype	_jc_soot_VoidType$vtype;

// Constructors
extern void _jc_soot_VoidType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_VoidType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_VoidType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_VoidType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_VoidType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_VoidType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_VoidType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_VoidType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_VoidType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_VoidType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_VoidType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_VoidType$object *_jc_soot_VoidType$method$v$1ec4381f84c71d19(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_VoidType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_VoidType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_VoidType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_VoidType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_VoidType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_VoidType$vmethods	soot_VoidType;
};

// Vtype
struct _jc_soot_VoidType$vtype {
	_jc_type			type;
	_jc_soot_VoidType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_VoidType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_VoidType$refs {
    _jc_soot_VoidType$sub_refs	soot_VoidType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_VoidType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_VoidType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_VoidType$sub_nonrefs	soot_VoidType;
};

// Object instance structure
struct _jc_soot_VoidType$object {
	_jc_soot_VoidType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_VoidType$vtype	*vtype;
	_jc_soot_VoidType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_VoidType$vtype _jc_soot_VoidType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_VoidType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_VoidType$class_object;

#endif	/* _JC_soot_VoidType_H_ */
